@@ -6,9 +6,9 @@ my $Informix = new Xymon::Monitor::Informix->new({
 										CONTRY => 1,
 										INFORMIXDIR => '/informix/',
 										LD_LIBRARY_PATH => '/informix/lib:/informix/lib/esql',
-										HOBBITHOME => '/home/hobbit/server/',									
+										HOBBITHOME => '/home/hobbit/client/',									
 	
 									});
 									
 
-$Informix->check();
\ No newline at end of file
+$Informix->check();
